@@ -28,6 +28,16 @@ interactive sessions.
 
 This may be fired multiple times per command, with other transformers input or
 output, so design any handlers for this carefully.
+
+.. code-block:: python
+
+    @events.on_transform_command
+    def _pipe_prev_command(cmd, **kw):
+        '''Pipe prev command e.g. `| grep 1` will be `<prev cmd> | grep 1`.'''
+        if cmd and cmd.startswith('| ') and __xonsh__.history:
+            return __xonsh__.history[-1].cmd.rstrip() + cmd.rstrip()
+        return cmd
+
 """,
 )
 
@@ -54,19 +64,48 @@ Parameters:
 * ``rtn``: The result of the command executed (``0`` for success)
 * ``out``: If xonsh stores command output, this is the output
 * ``ts``: Timestamps, in the order of ``[starting, ending]``
+
+Example:
+
+.. code-block:: python
+
+    @events.on_postcommand
+    def _prompt_err_command_again(cmd, rtn, out, ts):
+        '''If the result of executing the command is not zero, repeat the command on the next command prompt.'''
+        if rtn != 0:
+            $XONSH_PROMPT_NEXT_CMD = cmd.rstrip()
 """,
 )
 
 events.doc(
     "on_command_not_found",
     """
-on_command_not_found(cmd: list[str]) -> None
+on_command_not_found(cmd: list[str]) -> list[str] | tuple[str, ...] | None
 
 Fires if a command is not found (only in interactive sessions).
 
 Parameters:
 
 * ``cmd``: The command that was attempted
+
+Returns:
+
+* ``list[str]`` or ``tuple[str, ...]``: A replacement command to execute instead.
+  The first valid replacement from any handler will be used.
+* ``None``: To let the error be raised normally
+
+Note: If the replacement command also fails, the original error is shown.
+
+Example:
+
+.. code-block:: python
+
+    @events.on_command_not_found
+    def _vim_to_vi(cmd, **kwargs):
+        '''If vim not found let's try to use vi.'''
+        if cmd[0] == 'vim':
+            return ['vi'] + cmd[1:]
+
 """,
 )
 
@@ -251,12 +290,14 @@ class Shell:
                 ts=[time.time(), None],
                 locked=True,
                 filename=env.get("XONSH_HISTORY_FILE", None),
+                sessionid=XSH.sessionid,
             )
             env["XONSH_HISTORY_FILE"] = hist.filename
         else:
             XSH.history = hist = DummyHistory()
             env["XONSH_HISTORY_FILE"] = None
 
+        XSH.interface.history = XSH.history
         shell_type = self.choose_shell_type(shell_type, env)
 
         self.shell_type = env["SHELL_TYPE"] = shell_type
